<?php

/**
 * @file
 * Administration settings for the Manticore module.
 */

/**
 * Menu callback; Manticore administration settings.
 */
function manticore_admin() {
  $form['#attributes'] = array('enctype' => "multipart/form-data");
  $form['general'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
    '#description' => t('These are settings that apply to your site globally.'),
    '#collapsed' => FALSE,
    '#collapsible' => TRUE,
  );
  $form['general']['manticore_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Key'),
    '#description' => t('The Manticore MTC_KEY value.'),
    '#default_value' => variable_get('manticore_key', ''),
    '#required' => TRUE,
  );
  $form['general']['manticore_group'] = array(
    '#type' => 'textfield',
    '#title' => t('Group'),
    '#description' => t('The Manticore MTC_GROUP value.'),
    '#default_value' => variable_get('manticore_group', ''),
    '#required' => TRUE,
  );
  $form['general']['manticore_id'] = array(
    '#type' => 'textfield',
    '#title' => t('ID'),
    '#description' => t('The Manticore MTC_ID value.'),
    '#default_value' => variable_get('manticore_id', ''),
    '#required' => TRUE,
  );
  $form['general']['manticore_method'] = array(
    '#type' => 'radios',
    '#title' => t('Method'),
    '#description' => t('The method in which the Manticore API will be called.'),
    '#default_value' => variable_get('manticore_method', 'ManticoreDrupal'),
    '#required' => TRUE,
    '#options' => array(
      'ManticoreDrupal' => t('drupal_http_request()'),
      'ManticoreCurl' => t('cURL'),
    ),
  );

  // The Installation Code and Application File
  $form['installationcode'] = array(
    '#type' => 'fieldset',
    '#title' => t('Installation Code'),
    '#description' => t('Allows injection of the installation code for Manticore tracking.'),
    '#collapsed' => FALSE,
    '#collapsible' => TRUE,
  );
  $form['installationcode']['manticore_installationcode'] = array(
    '#type' => 'checkbox',
    '#title' => t('Installation Code'),
    '#description' => t('Inject the Manticore installation code at the footer of the site.'),
    '#default_value' => variable_get('manticore_installationcode', FALSE),
  );
  $form['installationcode']['manticore_applicationfile'] = array(
    '#type' => 'file',
    '#title' => t('Application File'),
    '#description' => t('Upload the downloaded Manticore application file here from the Installation Code tab.'),
    '#prefix' => variable_get('manticore_applicationfile_filepath', ''),
    '#size' => 20,
  );
  $form['#submit'][] = 'manticore_admin_applicationfile';
  return system_settings_form($form);
}

/**
 * Form API callback to handle the file upload.
 */
function manticore_admin_applicationfile($element, &$form_state) {
  if ($file = file_save_upload('manticore_applicationfile')) {
    if (file_copy($file)) {
      variable_set('manticore_applicationfile_filepath', $file->filepath);
    }
    else {
      form_set_error('manticore_admin', t("Failed to save the file."));
    }
  }
}

/**
 * Menu callback; The Manticore user administration settings.
 */
function manticore_admin_user() {
  // General settings relating to the users.
  $form['user'] = array(
    '#type' => 'fieldset',
    '#title' => t('User settings'),
    '#description' => t('These are settings that apply to your site globally.'),
    '#collapsed' => FALSE,
    '#collapsible' => TRUE,
  );
  $form['user']['manticore_when'] = array(
    '#type' => 'checkboxes',
    '#title' => t('When to update Manticore'),
    '#description' => t('Select at what point Manticore will be notified of user changes.'),
    '#default_value' => variable_get('manticore_when', array('after_update' => 'after_update')),
    '#options' => array(
      'insert' => t('User registration'),
      'after_update' => t('Updated profile'),
    ),
  );
  $form['user']['manticore_user_roles'] = array(
    '#type' => 'checkboxes',
    '#title' => t('User roles'),
    '#description' => t('Which user roles should be sent over to Manticore. If none are selected, all user roles will be sent.'),
    '#default_value' => variable_get('manticore_user_roles', array()),
    '#options' => user_roles(TRUE),
  );

  // Allow addition of the profile information.
  $form['fields'] = array(
    '#type' => 'fieldset',
    '#title' => t('Fields'),
    '#description' => t('Map the following given Manticore fields to the respective user field. These will represent parts of the user object. For example, you can map the Manticore first name to a custom profile field of "$user->profile_firstname" by entering "profile_firstname".'),
    '#collapsed' => FALSE,
    '#collapsible' => TRUE,
  );
  $fields = array(
    'firstname' => t('First Name'),
    'lastname' => t('Last Name'),
    'company' => t('Company'),
    'title' => t('Title'),
    'fax' => t('Fax'),
    'mobilephone' => t('Mobile Phone'),
    'workphone' => t('Work Phone'),
    'address1' => t('Address 1'),
    'address2' => t('Address 2'),
    'city' => t('City'),
    'region' => t('State/Region'),
    'postalcode' => t('Zip/Postal Code'),
    'country' => t('Country'),
  );
  foreach ($fields as $field => $title) {
    $form['fields']['manticore_' . $field] = array(
      '#title' => $title,
      '#type' => 'textfield',
      '#default_value' => variable_get('manticore_' . $field, ''),
    );
  }
  // Default the username as the Manticore account's first name instead of empty.
  $form['fields']['manticore_firstname']['#default_value'] = variable_get('manticore_firstname', 'name');

  // Provide the custom fields.
  $form['fields']['manticore_customfields'] = array(
    '#type' => 'textarea',
    '#title' => t('Custom Fields'),
    '#description' => t('Provide a list of custom profile fields that will be passed to Manticore. One field per line, the name and the value delimitered by a pipe. "name|value". Example: "Email_Opt_Out__c|profile_contact"'),
    '#default_value' => variable_get('manticore_customfields', ''),
  );

  // Provide the custom static fields.
  $form['fields']['manticore_customstaticfields'] = array(
    '#type' => 'textarea',
    '#title' => t('Static Fields'),
    '#description' => t('Provide a list of custom static fields that will be passed to Manticore. These values are like the custom fields, except these do not change based on the user profile information. "name|value". Example: "Latest_Lead_Source__c|Website".'),
    '#default_value' => variable_get('manticore_customstaticfields', ''),
  );

  return system_settings_form($form);
}
